@@ -1,5 +1,14 @@
+# SPDX-FileCopyrightText: © Antonio López Rivera <antonlopezr99@gmail.com>
+# SPDX-License-Identifier: GPL-3.0-only
+
+"""
+Plotting Methods
+----------------
+"""
+
 import inspect
 import difflib
+import warnings
 import numpy as np
 import matplotlib as mpl
 
@@ -200,17 +209,21 @@ class attributes:
                 self.z_upper_resize_pad = pad_z
                 self.z_lower_resize_pad = pad_z
 
-            self.ax.set_xlim3d(self.x_bounds[0] - self.x_lower_resize_pad,
-                               self.x_bounds[1] + self.x_upper_resize_pad)
-            self.ax.set_ylim3d(self.y_bounds[0] - self.y_lower_resize_pad,
-                               self.y_bounds[1] + self.y_upper_resize_pad)
-            self.ax.set_zlim3d(self.z_bounds[0] - self.y_lower_resize_pad,
-                               self.z_bounds[1] + self.y_upper_resize_pad)
+            # Set bounds ignoring warnings if bounds are equal
+            with warnings.catch_warnings():
+                warnings.simplefilter("ignore")
+                self.ax.set_xlim3d(self.x_bounds[0] - self.x_lower_resize_pad,
+                                   self.x_bounds[1] + self.x_upper_resize_pad)
+                self.ax.set_ylim3d(self.y_bounds[0] - self.y_lower_resize_pad,
+                                   self.y_bounds[1] + self.y_upper_resize_pad)
+                self.ax.set_zlim3d(self.z_bounds[0] - self.y_lower_resize_pad,
+                                   self.z_bounds[1] + self.y_upper_resize_pad)
 
     def method_title(self):
         if self.title is not None:
 
-            self.ax.set_title(self.title, y=self.title_y,
+            self.ax.set_title(self.title,
+                              y=self.title_y,
                               fontname=self.font if self.title_font is None else self.title_font,
                               weight=self.title_weight,
                               color=self.workspace_color if self.title_color is None else self.title_color,
@@ -474,7 +487,7 @@ class color:
 
     def method_cb(self):
         if self.color_bar is True:
-            if self.norm is None:
+            if self.color_rule is None:
                 return print_color("No norm selected for colorbar. Set norm=<parameter of choice>", "grey")
 
             # Obtain and apply limits
@@ -716,7 +729,7 @@ class scatter(plot, color):
 
     def __init__(self,
                  # Specifics
-                 x=None, y=None, z=None, point_size=30, marker="o",
+                 x=None, y=None, z=None, point_size=30, marker="o", facecolors=None,
                  # Specifics: color
                  alpha=1,
                  color='darkred',
@@ -837,13 +850,13 @@ class scatter(plot, color):
 
         if self.color_rule is not None:
             self.graph = self.ax.scatter(self.x, self.y, self.z, label=self.plot_label,
-                                         s=self.point_size, marker=self.marker,
+                                         s=self.point_size, marker=self.marker, facecolors=self.facecolors,
                                          c=self.color_rule, cmap=self.cmap,
                                          alpha=self.alpha)
             self.method_cb()
         else:
             self.graph = self.ax.scatter(self.x, self.y, self.z, label=self.plot_label,
-                                         s=self.point_size, marker=self.marker,
+                                         s=self.point_size, marker=self.marker, facecolors=self.facecolors,
                                          color=self.color,
                                          alpha=self.alpha)
 
